@@ -37,6 +37,10 @@ public:
     bool hasX11() const;
     bool hasWayland() const;
 
+    bool isSessionActive() const;
+    void activateSession();
+    void deactivateSession();
+
 Q_SIGNALS:
     void outputAdded(WOutput *output);
     void outputRemoved(WOutput *output);
@@ -44,6 +48,8 @@ Q_SIGNALS:
     void inputAdded(WInputDevice *input);
     void inputRemoved(WInputDevice *input);
 
+    void created();
+
 protected:
     void create(WServer *server) override;
     void destroy(WServer *server) override;
